@@ -401,7 +401,7 @@ static void resort_index (MUTTMENU *menu)
   menu->redraw = REDRAW_INDEX | REDRAW_STATUS;
 }
 
-static struct mapping_t IndexHelp[] = {
+static const struct mapping_t IndexHelp[] = {
   { N_("Quit"),  OP_QUIT },
   { N_("Del"),   OP_DELETE },
   { N_("Undel"), OP_UNDELETE },
@@ -555,12 +555,10 @@ int mutt_index_menu (void)
       if (menu->redraw & REDRAW_STATUS)
       {
 	menu_status_line (buf, sizeof (buf), menu, NONULL (Status));
-	CLEARLINE (option (OPTSTATUSONTOP) ? 0 : LINES-2);
+	move (option (OPTSTATUSONTOP) ? 0 : LINES-2, 0);
 	SETCOLOR (MT_COLOR_STATUS);
-        BKGDSET (MT_COLOR_STATUS);
 	mutt_paddstr (COLS, buf);
-	SETCOLOR (MT_COLOR_NORMAL);
-        BKGDSET (MT_COLOR_NORMAL);
+	NORMAL_COLOR;
 	menu->redraw &= ~REDRAW_STATUS;
       }
 
@@ -1013,7 +1011,6 @@ int mutt_index_menu (void)
 	  break;
 
 	CHECK_MSGCOUNT;
-        CHECK_VISIBLE;
 	CHECK_READONLY;
 	{
 	  int oldvcount = Context->vcount;
@@ -1021,15 +1018,19 @@ int mutt_index_menu (void)
 	  int check, newidx;
 	  HEADER *newhdr = NULL;
 
-	  /* threads may be reordered, so figure out what header the cursor
-	   * should be on. #3092 */
-	  newidx = menu->current;
-	  if (CURHDR->deleted)
-	    newidx = ci_next_undeleted (menu->current);
-	  if (newidx < 0)
-	    newidx = ci_previous_undeleted (menu->current);
-	  if (newidx >= 0)
-	    newhdr = Context->hdrs[Context->v2r[newidx]];
+	  /* don't attempt to move the cursor if there are no visible messages in the current limit */
+	  if (menu->current < Context->vcount)
+	  {
+	    /* threads may be reordered, so figure out what header the cursor
+	     * should be on. #3092 */
+	    newidx = menu->current;
+	    if (CURHDR->deleted)
+	      newidx = ci_next_undeleted (menu->current);
+	    if (newidx < 0)
+	      newidx = ci_previous_undeleted (menu->current);
+	    if (newidx >= 0)
+	      newhdr = Context->hdrs[Context->v2r[newidx]];
+	  }
 
 	  if ((check = mx_sync_mailbox (Context, &index_hint)) == 0)
 	  {
